[−][src]Enum unicode_types::geometric_shapes_extended::GeometricShapesExtended
An enum to represent all characters in the GeometricShapesExtended block.
Variants
BlackLeftDashPointingIsoscelesRightTriangle\u{1f780}: '🞀'
BlackUpDashPointingIsoscelesRightTriangle\u{1f781}: '🞁'
BlackRightDashPointingIsoscelesRightTriangle\u{1f782}: '🞂'
BlackDownDashPointingIsoscelesRightTriangle\u{1f783}: '🞃'
BlackSlightlySmallCircle\u{1f784}: '🞄'
MediumBoldWhiteCircle\u{1f785}: '🞅'
BoldWhiteCircle\u{1f786}: '🞆'
HeavyWhiteCircle\u{1f787}: '🞇'
VeryHeavyWhiteCircle\u{1f788}: '🞈'
ExtremelyHeavyWhiteCircle\u{1f789}: '🞉'
WhiteCircleContainingBlackSmallCircle\u{1f78a}: '🞊'
RoundTarget\u{1f78b}: '🞋'
BlackTinySquare\u{1f78c}: '🞌'
BlackSlightlySmallSquare\u{1f78d}: '🞍'
LightWhiteSquare\u{1f78e}: '🞎'
MediumWhiteSquare\u{1f78f}: '🞏'
BoldWhiteSquare\u{1f790}: '🞐'
HeavyWhiteSquare\u{1f791}: '🞑'
VeryHeavyWhiteSquare\u{1f792}: '🞒'
ExtremelyHeavyWhiteSquare\u{1f793}: '🞓'
WhiteSquareContainingBlackVerySmallSquare\u{1f794}: '🞔'
WhiteSquareContainingBlackMediumSquare\u{1f795}: '🞕'
SquareTarget\u{1f796}: '🞖'
BlackTinyDiamond\u{1f797}: '🞗'
BlackVerySmallDiamond\u{1f798}: '🞘'
BlackMediumSmallDiamond\u{1f799}: '🞙'
WhiteDiamondContainingBlackVerySmallDiamond\u{1f79a}: '🞚'
WhiteDiamondContainingBlackMediumDiamond\u{1f79b}: '🞛'
DiamondTarget\u{1f79c}: '🞜'
BlackTinyLozenge\u{1f79d}: '🞝'
BlackVerySmallLozenge\u{1f79e}: '🞞'
BlackMediumSmallLozenge\u{1f79f}: '🞟'
WhiteLozengeContainingBlackSmallLozenge\u{1f7a0}: '🞠'
ThinGreekCross\u{1f7a1}: '🞡'
LightGreekCross\u{1f7a2}: '🞢'
MediumGreekCross\u{1f7a3}: '🞣'
BoldGreekCross\u{1f7a4}: '🞤'
VeryBoldGreekCross\u{1f7a5}: '🞥'
VeryHeavyGreekCross\u{1f7a6}: '🞦'
ExtremelyHeavyGreekCross\u{1f7a7}: '🞧'
ThinSaltire\u{1f7a8}: '🞨'
LightSaltire\u{1f7a9}: '🞩'
MediumSaltire\u{1f7aa}: '🞪'
BoldSaltire\u{1f7ab}: '🞫'
HeavySaltire\u{1f7ac}: '🞬'
VeryHeavySaltire\u{1f7ad}: '🞭'
ExtremelyHeavySaltire\u{1f7ae}: '🞮'
LightFiveSpokedAsterisk\u{1f7af}: '🞯'
MediumFiveSpokedAsterisk\u{1f7b0}: '🞰'
BoldFiveSpokedAsterisk\u{1f7b1}: '🞱'
HeavyFiveSpokedAsterisk\u{1f7b2}: '🞲'
VeryHeavyFiveSpokedAsterisk\u{1f7b3}: '🞳'
ExtremelyHeavyFiveSpokedAsterisk\u{1f7b4}: '🞴'
LightSixSpokedAsterisk\u{1f7b5}: '🞵'
MediumSixSpokedAsterisk\u{1f7b6}: '🞶'
BoldSixSpokedAsterisk\u{1f7b7}: '🞷'
HeavySixSpokedAsterisk\u{1f7b8}: '🞸'
VeryHeavySixSpokedAsterisk\u{1f7b9}: '🞹'
ExtremelyHeavySixSpokedAsterisk\u{1f7ba}: '🞺'
LightEightSpokedAsterisk\u{1f7bb}: '🞻'
MediumEightSpokedAsterisk\u{1f7bc}: '🞼'
BoldEightSpokedAsterisk\u{1f7bd}: '🞽'
HeavyEightSpokedAsterisk\u{1f7be}: '🞾'
VeryHeavyEightSpokedAsterisk\u{1f7bf}: '🞿'
LightThreePointedBlackStar\u{1f7c0}: '🟀'
MediumThreePointedBlackStar\u{1f7c1}: '🟁'
ThreePointedBlackStar\u{1f7c2}: '🟂'
MediumThreePointedPinwheelStar\u{1f7c3}: '🟃'
LightFourPointedBlackStar\u{1f7c4}: '🟄'
MediumFourPointedBlackStar\u{1f7c5}: '🟅'
FourPointedBlackStar\u{1f7c6}: '🟆'
MediumFourPointedPinwheelStar\u{1f7c7}: '🟇'
ReverseLightFourPointedPinwheelStar\u{1f7c8}: '🟈'
LightFivePointedBlackStar\u{1f7c9}: '🟉'
HeavyFivePointedBlackStar\u{1f7ca}: '🟊'
MediumSixPointedBlackStar\u{1f7cb}: '🟋'
HeavySixPointedBlackStar\u{1f7cc}: '🟌'
SixPointedPinwheelStar\u{1f7cd}: '🟍'
MediumEightPointedBlackStar\u{1f7ce}: '🟎'
HeavyEightPointedBlackStar\u{1f7cf}: '🟏'
VeryHeavyEightPointedBlackStar\u{1f7d0}: '🟐'
HeavyEightPointedPinwheelStar\u{1f7d1}: '🟑'
LightTwelvePointedBlackStar\u{1f7d2}: '🟒'
HeavyTwelvePointedBlackStar\u{1f7d3}: '🟓'
HeavyTwelvePointedPinwheelStar\u{1f7d4}: '🟔'
CircledTriangle\u{1f7d5}: '🟕'
NegativeCircledTriangle\u{1f7d6}: '🟖'
CircledSquare\u{1f7d7}: '🟗'
NegativeCircledSquare\u{1f7d8}: '🟘'
LargeOrangeCircle\u{1f7e0}: '🟠'
LargeYellowCircle\u{1f7e1}: '🟡'
LargeGreenCircle\u{1f7e2}: '🟢'
LargePurpleCircle\u{1f7e3}: '🟣'
LargeBrownCircle\u{1f7e4}: '🟤'
LargeRedSquare\u{1f7e5}: '🟥'
LargeBlueSquare\u{1f7e6}: '🟦'
LargeOrangeSquare\u{1f7e7}: '🟧'
LargeYellowSquare\u{1f7e8}: '🟨'
LargeGreenSquare\u{1f7e9}: '🟩'
LargePurpleSquare\u{1f7ea}: '🟪'
LargeBrownSquare\u{1f7eb}: '🟫'
Methods
impl GeometricShapesExtended[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case